<?php

namespace Focus\Supervisor\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Focus\Supervisor\Interfaces\SupervisorRepositoryInterface;

class SupervisorPublicController extends BaseController
{
    // use SupervisorWorkflow;

    /**
     * Constructor.
     *
     * @param type \Focus\Supervisor\Interfaces\SupervisorRepositoryInterface $supervisor
     *
     * @return type
     */
    public function __construct(SupervisorRepositoryInterface $supervisor)
    {
        $this->repository = $supervisor;
        parent::__construct();
    }

    /**
     * Show supervisor's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $supervisors = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$supervisor::$supervisor.names'))
            ->view('$supervisor::public.supervisor.index')
            ->data(compact('$supervisors'))
            ->output();
    }

    /**
     * Show supervisor's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $supervisors = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$supervisor::$supervisor.names'))
            ->view('$supervisor::public.supervisor.index')
            ->data(compact('$supervisors'))
            ->output();
    }

    /**
     * Show supervisor.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $supervisor = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$supervisor->name . trans('$supervisor::$supervisor.name'))
            ->view('$supervisor::public.supervisor.show')
            ->data(compact('$supervisor'))
            ->output();
    }

}
