<?php

namespace Focus\Supervisor\Policies;

use Litepie\User\Contracts\UserPolicy;
use Focus\Supervisor\Models\Supervisor;

class SupervisorPolicy
{

    /**
     * Determine if the given user can view the supervisor.
     *
     * @param UserPolicy $user
     * @param Supervisor $supervisor
     *
     * @return bool
     */
    public function view(UserPolicy $user, Supervisor $supervisor)
    {
        if ($user->canDo('supervisor.supervisor.view') && $user->isAdmin()) {
            return true;
        }

        return $supervisor->user_id == user_id() && $supervisor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a supervisor.
     *
     * @param UserPolicy $user
     * @param Supervisor $supervisor
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('supervisor.supervisor.create');
    }

    /**
     * Determine if the given user can update the given supervisor.
     *
     * @param UserPolicy $user
     * @param Supervisor $supervisor
     *
     * @return bool
     */
    public function update(UserPolicy $user, Supervisor $supervisor)
    {
        if ($user->canDo('supervisor.supervisor.edit') && $user->isAdmin()) {
            return true;
        }

        return $supervisor->user_id == user_id() && $supervisor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given supervisor.
     *
     * @param UserPolicy $user
     * @param Supervisor $supervisor
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Supervisor $supervisor)
    {
        return $supervisor->user_id == user_id() && $supervisor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given supervisor.
     *
     * @param UserPolicy $user
     * @param Supervisor $supervisor
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Supervisor $supervisor)
    {
        if ($user->canDo('supervisor.supervisor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given supervisor.
     *
     * @param UserPolicy $user
     * @param Supervisor $supervisor
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Supervisor $supervisor)
    {
        if ($user->canDo('supervisor.supervisor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
