<?php

namespace Focus\Supervisor\Providers;

use Illuminate\Support\ServiceProvider;

class SupervisorServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'supervisor');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'supervisor');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('focus.supervisor', function ($app) {
            return $this->app->make('Focus\Supervisor\Supervisor');
        });

                // Bind Supervisor to repository
        $this->app->bind(
            'Focus\Supervisor\Interfaces\SupervisorRepositoryInterface',
            \Focus\Supervisor\Repositories\Eloquent\SupervisorRepository::class
        );

        $this->app->register(\Focus\Supervisor\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Focus\Supervisor\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['focus.supervisor'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('focus/supervisor.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/supervisor')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/supervisor')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
